@@ -14,5 +14,5 @@ nexprs <- function(names) {
 exprs_project <- function(rel, exprs, .data) {
   out_rel <- rel_project(rel, exprs)
   out <- rel_to_df(out_rel)
-  dplyr_reconstruct_dispatch(out, .data)
+  dplyr_reconstruct(out, .data)
 }
