@@ -43,7 +43,6 @@ duckplyr_macros <- c(
   "&" = "(x, y) AS (x AND y)",
   "!" = "(x) AS (NOT x)",
   "any" = "(x) AS (bool_or(x))",
-  "desc" = "(x) AS (-x)",
   "n_distinct" = "(x) AS (COUNT(DISTINCT x))",
   #
   "wday" = "(x) AS CAST(weekday(CAST (x AS DATE)) + 1 AS int32)",
@@ -61,7 +60,7 @@ create_default_duckdb_connection <- function() {
   drv <- duckdb::duckdb()
   con <- DBI::dbConnect(drv)
 
-  DBI::dbExecute(con, "set memory_limit='1GB'")
+  # DBI::dbExecute(con, "set memory_limit='1GB'")
   DBI::dbExecute(con, paste0("pragma temp_directory='", tempdir(), "'"))
 
   duckdb$rapi_load_rfuns(drv@database_ref)
@@ -238,10 +237,11 @@ rel_aggregate.duckdb_relation <- function(rel, groups, aggregates, ...) {
 }
 
 #' @export
-rel_order.duckdb_relation <- function(rel, orders, ...) {
+rel_order.duckdb_relation <- function(rel, orders, ascending = NULL, ...) {
+
   duckdb_orders <- to_duckdb_exprs(orders)
 
-  out <- duckdb$rel_order(rel, duckdb_orders)
+  out <- duckdb$rel_order(rel, duckdb_orders, ascending)
 
   meta_rel_register(out, expr(duckdb$rel_order(
     !!meta_rel_get(rel)$name,
