@@ -1,5 +1,4 @@
-#' @export
-methods_restore <- function() {
+methods_restore_impl <- function() {
   vctrs::s3_register("dplyr::add_count", "data.frame", dplyr$add_count.data.frame)
   vctrs::s3_register("dplyr::anti_join", "data.frame", dplyr$anti_join.data.frame)
   vctrs::s3_register("dplyr::arrange", "data.frame", dplyr$arrange.data.frame)
@@ -12,11 +11,22 @@ methods_restore <- function() {
   vctrs::s3_register("dplyr::do", "data.frame", dplyr$do.data.frame)
   vctrs::s3_register("dplyr::filter", "data.frame", dplyr$filter.data.frame)
   vctrs::s3_register("dplyr::full_join", "data.frame", dplyr$full_join.data.frame)
+  vctrs::s3_register("dplyr::group_by", "data.frame", dplyr$group_by.data.frame)
+  vctrs::s3_register("dplyr::group_indices", "data.frame", dplyr$group_indices.data.frame)
+  vctrs::s3_register("dplyr::group_keys", "data.frame", dplyr$group_keys.data.frame)
+  vctrs::s3_register("dplyr::group_map", "data.frame", dplyr$group_map.data.frame)
+  vctrs::s3_register("dplyr::group_modify", "data.frame", dplyr$group_modify.data.frame)
+  vctrs::s3_register("dplyr::group_nest", "data.frame", dplyr$group_nest.data.frame)
+  vctrs::s3_register("dplyr::group_size", "data.frame", dplyr$group_size.data.frame)
+  vctrs::s3_register("dplyr::group_split", "data.frame", dplyr$group_split.data.frame)
+  vctrs::s3_register("dplyr::group_trim", "data.frame", dplyr$group_trim.data.frame)
   vctrs::s3_register("dplyr::group_vars", "data.frame", dplyr$group_vars.data.frame)
+  vctrs::s3_register("dplyr::groups", "data.frame", dplyr$groups.data.frame)
   vctrs::s3_register("dplyr::inner_join", "data.frame", dplyr$inner_join.data.frame)
   vctrs::s3_register("dplyr::intersect", "data.frame", dplyr$intersect.data.frame)
   vctrs::s3_register("dplyr::left_join", "data.frame", dplyr$left_join.data.frame)
   vctrs::s3_register("dplyr::mutate", "data.frame", dplyr$mutate.data.frame)
+  vctrs::s3_register("dplyr::n_groups", "data.frame", dplyr$n_groups.data.frame)
   vctrs::s3_register("dplyr::nest_by", "data.frame", dplyr$nest_by.data.frame)
   vctrs::s3_register("dplyr::nest_join", "data.frame", dplyr$nest_join.data.frame)
   vctrs::s3_register("dplyr::pull", "data.frame", dplyr$pull.data.frame)
@@ -31,6 +41,7 @@ methods_restore <- function() {
   vctrs::s3_register("dplyr::rows_patch", "data.frame", dplyr$rows_patch.data.frame)
   vctrs::s3_register("dplyr::rows_update", "data.frame", dplyr$rows_update.data.frame)
   vctrs::s3_register("dplyr::rows_upsert", "data.frame", dplyr$rows_upsert.data.frame)
+  vctrs::s3_register("dplyr::rowwise", "data.frame", dplyr$rowwise.data.frame)
   vctrs::s3_register("dplyr::select", "data.frame", dplyr$select.data.frame)
   vctrs::s3_register("dplyr::semi_join", "data.frame", dplyr$semi_join.data.frame)
   vctrs::s3_register("dplyr::setdiff", "data.frame", dplyr$setdiff.data.frame)
