@@ -26,13 +26,18 @@ on_load({
 #' tibble(a = 1:3) %>%
 #'   mutate(b = a + 1)
 methods_overwrite <- function() {
-  cli::cli_inform(c(i = "Overwriting {.pkg dplyr} methods with {.pkg duckplyr} methods"))
+  cli::cli_inform(
+    c(
+      v = "Overwriting {.pkg dplyr} methods with {.pkg duckplyr} methods.",
+      i = "Turn off with {.run duckplyr::methods_restore()}."
+    )
+  )
   methods_overwrite_impl()
 }
 
 #' @rdname methods_overwrite
 #' @export
 methods_restore <- function() {
-  cli::cli_inform(c(i = "Restoring {.pkg dplyr} methods"))
+  cli::cli_inform(c(i = "Restoring {.pkg dplyr} methods."))
   methods_restore_impl()
 }
