@@ -8,6 +8,9 @@ test_that("no homonyms", {
   names_duckplyr <- ls(duckplyr)
 
   purrr_names <- c(
+    # https://github.com/tidyverse/dplyr/pull/7029
+    "join_ptype_common",
+
     "map", "walk", "map_lgl", "map_int", "map_dbl", "map_chr",
     ".rlang_purrr_map_mold", "map2", "map2_lgl", "map2_int",
     "map2_dbl", "map2_chr", "imap", "pmap", ".rlang_purrr_args_recycle",
