@@ -1,6 +1,4 @@
 test_that("can construct expressions", {
-  # FIXME: Restore after https://github.com/cynkra/constructive/pull/199
-  skip_on_ci()
   skip_on_cran()
 
   expect_snapshot({
@@ -9,3 +7,12 @@ test_that("can construct expressions", {
     relexpr_function("+", list(relexpr_reference("column"), relexpr_constant(42, alias = "fortytwo")))
   })
 })
+
+test_that(".env pronoun works", {
+  withr::local_envvar(DUCKPLYR_FORCE = TRUE)
+
+  a <- 2
+  data <- data.frame(a = 1)
+  out <- data %>% as_duckplyr_df() %>% mutate(b = .env$a)
+  expect_equal(out, data.frame(a = 1, b = 2) %>% as_duckplyr_df())
+})
