@@ -1,5 +1,5 @@
 test_that("Roundtrip to CSV works", {
-  df <- data.frame(a = 1:3, b = letters[4:6])
+  df <- tibble(a = 1:3, b = letters[4:6])
 
   path_csv <- withr::local_tempfile(fileext = ".csv")
 
